Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(101)

Unified Diff: content/browser/media/webrtc_internals.h

Issue 1272223003: Implement writing mic audio input data to file for debugging purposes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/media/webrtc_internals.h
diff --git a/content/browser/media/webrtc_internals.h b/content/browser/media/webrtc_internals.h
index 8ad1f2cba7bbc664409d036704bb99c564eb8504..a1d7cdf0839502e7dde2126bd8009e40aded7bc4 100644
--- a/content/browser/media/webrtc_internals.h
+++ b/content/browser/media/webrtc_internals.h
@@ -87,28 +87,25 @@ class CONTENT_EXPORT WebRTCInternals : public RenderProcessHostObserver,
// Sends all update data to |observer|.
void UpdateObserver(WebRTCInternalsUIObserver* observer);
- // Enables or disables AEC dump (diagnostic echo canceller recording).
- void EnableAecDump(content::WebContents* web_contents);
- void DisableAecDump();
+ // Enables or disables diagnostic audio recordings for debugging purposes.
+ void EnableAudioDebugRecordings(content::WebContents* web_contents);
+ void DisableAudioDebugRecordings();
- bool aec_dump_enabled() {
- return aec_dump_enabled_;
- }
-
- base::FilePath aec_dump_file_path() {
- return aec_dump_file_path_;
- }
+ bool IsAudioDebugRecordingsEnabled() const;
+ const base::FilePath& GetAudioDebugRecordingsFilePath() const;
void ResetForTesting();
private:
friend struct base::DefaultLazyInstanceTraits<WebRTCInternals>;
- FRIEND_TEST_ALL_PREFIXES(WebRtcAecDumpBrowserTest, CallWithAecDump);
- FRIEND_TEST_ALL_PREFIXES(WebRtcAecDumpBrowserTest,
- CallWithAecDumpEnabledThenDisabled);
- FRIEND_TEST_ALL_PREFIXES(WebRtcAecDumpBrowserTest, TwoCallsWithAecDump);
+ FRIEND_TEST_ALL_PREFIXES(WebRtcAudioDebugRecordingsBrowserTest,
+ CallWithAudioDebugRecordings);
+ FRIEND_TEST_ALL_PREFIXES(WebRtcAudioDebugRecordingsBrowserTest,
+ CallWithAudioDebugRecordingsEnabledThenDisabled);
+ FRIEND_TEST_ALL_PREFIXES(WebRtcAudioDebugRecordingsBrowserTest,
+ TwoCallsWithAudioDebugRecordings);
FRIEND_TEST_ALL_PREFIXES(WebRtcInternalsTest,
- AecRecordingFileSelectionCanceled);
+ AudioDebugRecordingsFileSelectionCanceled);
WebRTCInternals();
~WebRTCInternals() override;
@@ -128,8 +125,9 @@ class CONTENT_EXPORT WebRTCInternals : public RenderProcessHostObserver,
void OnRendererExit(int render_process_id);
#if defined(ENABLE_WEBRTC)
- // Enables AEC dump on all render process hosts using |aec_dump_file_path_|.
- void EnableAecDumpOnAllRenderProcessHosts();
+ // Enables diagnostic audio recordings on all render process hosts using
+ // |audio_debug_recordings_file_path_|.
+ void EnableAudioDebugRecordingsOnAllRenderProcessHosts();
#endif
// Called whenever an element is added to or removed from
@@ -167,9 +165,9 @@ class CONTENT_EXPORT WebRTCInternals : public RenderProcessHostObserver,
// For managing select file dialog.
scoped_refptr<ui::SelectFileDialog> select_file_dialog_;
- // AEC dump (diagnostic echo canceller recording) state.
- bool aec_dump_enabled_;
- base::FilePath aec_dump_file_path_;
+ // Diagnostic audio recording state.
+ bool audio_debug_recordings_;
+ base::FilePath audio_debug_recordings_file_path_;
// While |peer_connection_data_| is non-empty, hold an instance of
// PowerSaveBlocker. This prevents the application from being suspended while
« no previous file with comments | « content/browser/media/webrtc_audio_debug_recordings_browsertest.cc ('k') | content/browser/media/webrtc_internals.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698